Affiliated packages — lenstronomy 1.9.1 documentation

# Affiliated packages

Here is an (incomplete) list of packages and wrappers that are using lenstronomy in various ways for specific scientific applications:

- baobab: Training data generator for hierarchically modeling of strong lenses with Bayesian neural networks.
- dolphin: Automated pipeline for lens modeling based on lenstronomy.
- hierArc: Hierarchical Bayesian time-delay cosmography to infer the Hubble constant and galaxy density profiles in conjunction with lenstronomy.
- lenstruction: Versatile tool for cluster source reconstruction and local perturbative lens modeling.
- SLITronomy: Updated and improved version of the Sparse Lens Inversion Technique (SLIT), developed within the framework of lenstronomy.
- LSSTDESC SLSprinkler: The DESC SL (Strong Lensing) Sprinkler adds strongly lensed AGN and SNe to simulated catalogs and generates postage stamps for these systems.
- lensingGW: A Python package designed to handle both strong and microlensing of compact binaries and the related gravitational-wave signals.
- ovejero: Conducts hierarchical inference of strongly-lensed systems with Bayesian neural networks.
- h0rton: H0 inferences with Bayesian neural network lens modeling.
- deeplenstronomy: Tool for simulating large datasets for applying deep learning to strong gravitational lensing.
- pyHalo: Tool for rendering full substructure mass distributions for gravitational lensing simulations.

These packages come with their own documentation and examples - so check them out!

## guidelines for affiliated packages

If you have a package/wrapper/analysis pipeline that is open source and you would like to have it advertised here, please let the developers know! Before you write your own wrapper and scripts in executing lenstronomy for your purpose check out the list of existing add-on packages. Affiliated packages should not duplicate the core routines of lenstronomy and whenever possible make use of the lenstronomy modules. The packages should be maintained to keep up with the development of lenstronomy. Please also make sure the citation guidelines are presented.